@@ -100,7 +100,7 @@ class Coord(LazyData):
     def convert_standard_time_to_datetime(self):
         from cis.time_util import convert_std_time_to_datetime, cis_standard_time_unit
         if self.units == cis_standard_time_unit:
-            self._data = convert_std_time_to_datetime(self.data)
+            self.data = convert_std_time_to_datetime(self.data)
             self.units = "DateTime Object"
 
     def set_longitude_range(self, range_start):
@@ -119,8 +119,9 @@ class Coord(LazyData):
 
         :return: Copied :class:`Coord`
         """
+        from copy import deepcopy
         data = data if data is not None else numpy.ma.copy(self.data)  # Will call lazy load method
-        return Coord(data, self.metadata, axis=self.axis)
+        return Coord(data, deepcopy(self.metadata), axis=deepcopy(self.axis))
 
 
 class CoordList(list):
